# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LogReplayNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LogReplayNode.proto\x12\rLogReplayNode\x1a\x0c\x43ommon.proto\";\n\x08log_info\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0f\n\x07logging\x18\x02 \x03(\t\"8\n\x0blin_message\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\r\"e\n\x12lin_message_decode\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\r\x12\x12\n\ndecode_str\x18\x04 \x01(\t\"8\n\x0b\x63\x61n_message\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\r\"e\n\x12\x63\x61n_message_decode\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\r\x12\x12\n\ndecode_str\x18\x04 \x01(\t\"1\n\x0flin_decode_role\x12\x10\n\x08\x63hannels\x18\x01 \x03(\r\x12\x0c\n\x04ldfs\x18\x02 \x03(\t\"T\n\x0f\x63\x61n_decode_role\x12\x18\n\x10\x63\x61n_db_file_path\x18\x01 \x01(\t\x12\x10\n\x08\x63hannels\x18\x02 \x03(\r\x12\x15\n\rcluster_names\x18\x03 \x03(\t2\xfa\x03\n\rLogReplayNode\x12/\n\x08StartLog\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12\x36\n\nGetLogInfo\x12\r.Common.empty\x1a\x17.LogReplayNode.log_info\"\x00\x12.\n\x07StopLog\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12L\n\tDecodeLin\x12\x1a.LogReplayNode.lin_message\x1a!.LogReplayNode.lin_message_decode\"\x00\x12L\n\tDecodeCan\x12\x1a.LogReplayNode.can_message\x1a!.LogReplayNode.can_message_decode\"\x00\x12\x44\n\x10\x41\x64\x64LinDecodeRole\x12\x1e.LogReplayNode.lin_decode_role\x1a\x0e.Common.result\"\x00\x12\x44\n\x10\x41\x64\x64\x43\x61nDecodeRole\x12\x1e.LogReplayNode.can_decode_role\x1a\x0e.Common.result\"\x00\x12(\n\x05Reset\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_LOG_INFO = DESCRIPTOR.message_types_by_name['log_info']
_LIN_MESSAGE = DESCRIPTOR.message_types_by_name['lin_message']
_LIN_MESSAGE_DECODE = DESCRIPTOR.message_types_by_name['lin_message_decode']
_CAN_MESSAGE = DESCRIPTOR.message_types_by_name['can_message']
_CAN_MESSAGE_DECODE = DESCRIPTOR.message_types_by_name['can_message_decode']
_LIN_DECODE_ROLE = DESCRIPTOR.message_types_by_name['lin_decode_role']
_CAN_DECODE_ROLE = DESCRIPTOR.message_types_by_name['can_decode_role']
log_info = _reflection.GeneratedProtocolMessageType('log_info', (_message.Message,), {
  'DESCRIPTOR' : _LOG_INFO,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.log_info)
  })
_sym_db.RegisterMessage(log_info)

lin_message = _reflection.GeneratedProtocolMessageType('lin_message', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_message)
  })
_sym_db.RegisterMessage(lin_message)

lin_message_decode = _reflection.GeneratedProtocolMessageType('lin_message_decode', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE_DECODE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_message_decode)
  })
_sym_db.RegisterMessage(lin_message_decode)

can_message = _reflection.GeneratedProtocolMessageType('can_message', (_message.Message,), {
  'DESCRIPTOR' : _CAN_MESSAGE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.can_message)
  })
_sym_db.RegisterMessage(can_message)

can_message_decode = _reflection.GeneratedProtocolMessageType('can_message_decode', (_message.Message,), {
  'DESCRIPTOR' : _CAN_MESSAGE_DECODE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.can_message_decode)
  })
_sym_db.RegisterMessage(can_message_decode)

lin_decode_role = _reflection.GeneratedProtocolMessageType('lin_decode_role', (_message.Message,), {
  'DESCRIPTOR' : _LIN_DECODE_ROLE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_decode_role)
  })
_sym_db.RegisterMessage(lin_decode_role)

can_decode_role = _reflection.GeneratedProtocolMessageType('can_decode_role', (_message.Message,), {
  'DESCRIPTOR' : _CAN_DECODE_ROLE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.can_decode_role)
  })
_sym_db.RegisterMessage(can_decode_role)

_LOGREPLAYNODE = DESCRIPTOR.services_by_name['LogReplayNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOG_INFO._serialized_start=52
  _LOG_INFO._serialized_end=111
  _LIN_MESSAGE._serialized_start=113
  _LIN_MESSAGE._serialized_end=169
  _LIN_MESSAGE_DECODE._serialized_start=171
  _LIN_MESSAGE_DECODE._serialized_end=272
  _CAN_MESSAGE._serialized_start=274
  _CAN_MESSAGE._serialized_end=330
  _CAN_MESSAGE_DECODE._serialized_start=332
  _CAN_MESSAGE_DECODE._serialized_end=433
  _LIN_DECODE_ROLE._serialized_start=435
  _LIN_DECODE_ROLE._serialized_end=484
  _CAN_DECODE_ROLE._serialized_start=486
  _CAN_DECODE_ROLE._serialized_end=570
  _LOGREPLAYNODE._serialized_start=573
  _LOGREPLAYNODE._serialized_end=1079
# @@protoc_insertion_point(module_scope)
